.. _format-overview:

File formats
============

.. csv-table::
   :header: "Name", "File extension", "Read", "Write"

   "Arbor Cable Cell", "``acc``", "✓", "✓"
   "SWC", "``swc``", "✓", "✗"
   "NMODL", "``mod``", "✓", "✗"
   "NeuroML2", "``nml``", "✓", "✗"
   "Neurolucida", "``asc``", "✓", "✗"

.. toctree::
   :maxdepth: 2

   cable_cell
   asc
   neuroml
   nmodl
   swc
